@@ -5,11 +5,12 @@
 #                                                                              #
 #                                                                              #
 #   Date: December 22, 2011                                                    #
-#   Last modification on: October 17, 2012                                     #
+#   Last modification on: December  2, 2016                                    #
 ################################################################################
 
 plot.select.parfm <- function(x, 
                               mar=c(2.5, 2, 1.5, .5),
+                              ty = 'b',
                               ...){
   par(mfrow=c(1, 3))
   
@@ -30,24 +31,30 @@ plot.select.parfm <- function(x,
   
   for (i in 1:nrow(x$AIC)) points(
     (1:ncol(x$AIC)), x$AIC[i, ],
-    pch=i, cex=1.5)
+    pch = 19 + i, cex = 1.5, ty = ty, bg = i)
   
   
   ### --- names --- ###
   par(mar=mar)
-  plot(0:2, 0:2, xaxt="n", yaxt="n", bty="n", xlab="", ylab="",
-       ty="n")
+  plot(0:2, 0:2, xaxt = "n", yaxt = "n", bty = "n", ann = FALSE,
+       ty = "n")
   
-  legend(c(.3, 1.7), c(1, 1.75),
-         c(exponential="exponential", weibull="Weibull", 
-           inweibull="inverse Weibull",
-           gompertz="Gompertz", loglogistic="loglogistic", 
-           lognormal="lognormal")[rownames(x$AIC)],
-         pch=1:nrow(x$AIC), 
-         bg="white", bty="n",
-         ncol=1, cex=1.5, xjust=.5)
+  legend("top", #c(.3, 1.7), c(1, 1.75),
+         title = 'Baseline',
+         c(exponential = "exponential",
+           weibull = "Weibull", 
+           inweibull = "inverse Weibull",
+           gompertz = "Gompertz",
+           loglogistic = "loglogistic", 
+           lognormal = "logNormal",
+           logskewnormal = "logSkewNormal")[rownames(x$AIC)],
+         pch = {if(ty == 'l') NULL else 19 + 1:nrow(x$AIC)},
+         pt.bg = 1:nrow(x$AIC),
+         bg = "white", bty = "n", lty = ifelse(ty == 'p', 0, 1),
+         ncol = 1, cex = 1.5, xjust = .5)
   
-  legend(c(0, 2), c(.25, 1), yjust=1,
+  legend("bottom", #c(0, 2), c(.25, 1), yjust=1,
+         title = 'Frailty distribution',
          mapply(paste, 
                 c(none="No",
                   gamma="Ga",
@@ -83,6 +90,6 @@ plot.select.parfm <- function(x,
   
   for (i in 1:nrow(x$BIC)) points(
     (1:ncol(x$BIC)), x$BIC[i, ],
-    pch=i, cex=1.5)
+    pch = 19 + i, cex = 1.5, ty = ty, bg = i)
 }
 
